@@ -1,4 +1,4 @@
-from magicbus import bus
+from magicbus.process import ProcessBus
 from magicbus.plugins import servers
 from magicbus.test import assertEqual, WebService, WebHandler
 
@@ -8,30 +8,30 @@ from magicbus.test import assertEqual, WebService, WebHandler
 
 class Handler(WebHandler):
 
-    bus = bus
-
     def do_GET(self):
         if self.path == '/':
             self.respond("Hello World")
         elif self.path == '/ctrlc':
             self.respond("okey-doke")
             raise KeyboardInterrupt
-        elif self.path == '/exit':
-            self.respond("ok")
-            self.bus.exit()
         else:
             self.respond(status=404)
-service = WebService(handler_class=Handler)
-adapter = servers.ServerPlugin(bus, service, service.address)
-adapter.subscribe()
 
 
 class TestServers(object):
 
     def test_keyboard_interrupt(self):
+        bus = ProcessBus()
+
+        Handler.bus = bus
+        service = WebService(address=('127.0.0.1', 38002),
+                             handler_class=Handler)
+        adapter = servers.ServerPlugin(bus, service, service.address)
+        adapter.subscribe()
+
         # Raise a keyboard interrupt in the HTTP server's main thread.
-        bus.start()
+        bus.transition("RUN")
         resp = service.do_GET("/ctrlc")
         assertEqual(resp.status, 200)
         bus.block()
-        assertEqual(bus.state, bus.states.EXITING)
+        assertEqual(bus.state, "EXITED")
